C
C *** READ OF SPECTRUM AMPLITUDE DATA FROM AND SPCOUT FILE DATA ***
C
      SUBROUTINE SPCARD(NOM,MOM,SPCA)
C
C ** NOM     : TOTAL NUMBER OF CIRCULAR FREQUENCY
C ** MOM     : NOM IN MAIN PROGRAM DIMENSION
C ** SPCA(I) : SPECTRUM AMPLITUDE
C
      IMPLICIT REAL*8(A-H,O-Z)
      DIMENSION SPCA(MOM)
C
C *** READ SPETRUM AMPLITUDE DATA FROM SPCOUT.DAT ***
C
      WRITE(*,1000)
      OPEN(6,FILE='SPC.DAT')
      DO 100 IOM=1,NOM,8
      READ(6,1010)(SPCA((IOM-1)+I),I=1,8)
      WRITE(*,1010)(SPCA((IOM-1)+I),I=1,8)
  100 CONTINUE
      CLOSE(6)
 1000 FORMAT(/' FROM SUBROUTINE SPCARD : AMPLITUDE SPECTRUM DATA ECHO')
 1010 FORMAT(8F10.4)
   10 WRITE(*,*)
C
      RETURN
      END
